@@ -29,8 +29,10 @@
  *   
  *   
 */
+#include "config.h"
 #include "aboutdialog.h"
 //---------------------------------------------------------------------------
 AboutDialog::AboutDialog(QWidget *parent) : QDialog(parent) {
   setupUi(this);
+  this->versionEdit->setText(QString("ophcrack ").append(PACKAGE_VERSION));
 }
