@@ -33,12 +33,13 @@
 #define GRAPHDIALOG_H
 
 #include <QDialog>
-#include <qwt_plot.h>
-#include <qwt_plot_curve.h>
-#include <qwt_plot_grid.h>
-#include <qwt_interval_data.h>
+#include <QtCharts/QChartView>
+#include <QtCharts/QBarSet>
+#include <QtCharts/QLineSeries>
+#include <QtCharts/QValueAxis>
+using namespace QtCharts;
+
 
-#include "histogram_item.h"
 #include "ophstat.h"
 #include "list.h"
 #include "ui_graphdialog.h"
@@ -52,26 +53,28 @@ public:
   void plot(ophstat_t *stats, int crack_time);
 
 private:
-  void plotHistoLength(uint32_t *val, QwtPlot *plot);
-  void plotHistoCategory(uint32_t *val, QwtPlot *plot);
-  void plotCurve(list_t *list, int crack_time, QwtPlot *plot);
+  void initBarGraph(const int numValues, QChart* chart, QBarSet *set, QValueAxis *axisX, QValueAxis *axisY, QString title, const QColor color);
+  void plotHistoLength(uint32_t *val, QChartView *view);
+  void plotHistoCategory(uint32_t *val, QChartView *view);
+  void plotCurve(list_t *list, int crack_time, QChartView *view);
 
 private:
 
-  QwtArray<QwtDoubleInterval> lengthX;
-  QwtArray<double> lengthY;
-  HistogramItem *lengthHistogram;
-  QwtPlotGrid *lengthGrid;
+  QBarSet *lengthSet;
+  QChart *lengthHistogram;
+  QValueAxis *lengthAxisX;
+  QValueAxis *lengthAxisY;
 
-  QwtArray<QwtDoubleInterval> categoryX;
-  QwtArray<double> categoryY;
-  HistogramItem *categoryHistogram;
-  QwtPlotGrid *categoryGrid;
-  
-  QwtArray<double> timeX;
-  QwtArray<double> timeY;
-  QwtPlotCurve *timeCurve;
-  QwtPlotGrid *timeGrid;
+  QBarSet *categorySet;
+  QChart *categoryHistogram;
+  QValueAxis *categoryAxisX;
+  QValueAxis *categoryAxisY;
+
+  QLineSeries *timeSeries;
+  QVector<QPointF> *timeVector;
+  QChart *timeCurve;
+  QValueAxis *timeAxisX;
+  QValueAxis *timeAxisY;
 
 };
 
