@@ -44,6 +44,8 @@
 #endif
 #ifdef HAVE_GUI
 #include <QApplication>
+#include <QtCharts>
+using namespace QtCharts;
 #endif
 
 #include "ophcrack.h"
@@ -287,15 +289,15 @@ int load_hashes_sam(ophcrack_t *crack, int id) {
   // Check if there was a problem while reading the SYSTEM or SAM file.
 
   else if (npwds == -3) {
-    fprintf(stderr, 
-	    "A problem occured while reading the SYSTEM file found in %s.\n", 
+    fprintf(stderr,
+	    "A problem occurred while reading the SYSTEM file found in %s.\n",
 	    arg->samdir);
     exit(1);
   }
 
   else if (npwds == -4) {
     fprintf(stderr,
-	    "A problem occured while reading the SAM file found in %s.\n", 
+	    "A problem occurred while reading the SAM file found in %s.\n",
 	    arg->samdir);
     exit(1);
   }
