@@ -56,9 +56,7 @@ OphcrackGUI::OphcrackGUI(ophcrack_t *crack) : QMainWindow() {
   tableDialog = 0;
   helpDialog = 0;
   exportDialog = 0;
-#if HAVE_QWT
   graphDialog = 0;
-#endif
 
   fsm_reset_preload(fsm);
   fsm_reset_bforce(fsm);
@@ -181,12 +179,8 @@ OphcrackGUI::OphcrackGUI(ophcrack_t *crack) : QMainWindow() {
   connect(crackButton, SIGNAL(clicked()), this, SLOT(startStopCrack()));
   connect(tableButton, SIGNAL(clicked()), this, SLOT(selectTables()));
   connect(resetButton, SIGNAL(clicked()), this, SLOT(resetStat()));
-#if HAVE_QWT
   connect(graphButton, SIGNAL(clicked()), this, SLOT(displayGraph()));
-#else
-  graphButton->setEnabled(false);
-#endif
-  connect(threadSlider, SIGNAL(valueChanged(int)), this, SLOT(threadChanged(int)));
+  connect(threadSpinBox, SIGNAL(valueChanged(int)), this, SLOT(threadChanged(int)));
   connect(hreduxSlider, SIGNAL(valueChanged(int)), this, SLOT(hreduxChanged(int)));
   connect(queueSlider, SIGNAL(valueChanged(int)), this, SLOT(queueChanged(int)));
   connect(defaultButton, SIGNAL(clicked()), this, SLOT(defaultConfig()));
@@ -559,10 +553,10 @@ void OphcrackGUI::loadSamFile(void) {
     // Check if there was a problem while reading the SYSTEM or SAM file.
     
     else if (npwds == -3)
-      buff = QString("A problem occured while reading the SYSTEM file found in %1.").arg(arg->samdir);
+      buff = QString("A problem occurred while reading the SYSTEM file found in %1.").arg(arg->samdir);
     
     else if (npwds == -4) 
-      buff = QString("A problem occured while reading the SAM file found in %1.").arg(arg->samdir);
+      buff = QString("A problem occurred while reading the SAM file found in %1.").arg(arg->samdir);
 
     if (npwds <= 0) {
       QMessageBox msgBox(QMessageBox::Warning,
@@ -748,7 +742,6 @@ void OphcrackGUI::resetStat(void) {
 }
 //---------------------------------------------------------------------------
 void OphcrackGUI::displayGraph(void) {
-#if HAVE_QWT
   if (graphDialog == 0) {
     graphDialog = new GraphDialog(this);
   }
@@ -757,7 +750,6 @@ void OphcrackGUI::displayGraph(void) {
   
   graphDialog->plot(crack->stat, tv_sec);
   graphDialog->show();
-#endif
 }
 //---------------------------------------------------------------------------
 void OphcrackGUI::handleMessages(void) {
@@ -777,12 +769,10 @@ void OphcrackGUI::handleMessages(void) {
       msg_found_t *found = (msg_found_t*)msg->data;
       hash_t *hsh = found->hsh;
 
-#if HAVE_QWT
       int tv_sec = (int) tm_total.tv_sec;
 
       if (graphDialog != 0 && graphDialog->isVisible()) 
 	graphDialog->plot(crack->stat, tv_sec);
-#endif
       hashModel->updateHash(hsh);
     }
 
@@ -1169,7 +1159,7 @@ void OphcrackGUI::updateConfig(void) {
   int hideuname = arg->hideuname;
   int auditmode = arg->auditmode;
 
-  threadSlider->setSliderPosition(nthreads);
+  threadSpinBox->setValue(nthreads);
   threadChanged(nthreads);
 
   hreduxSlider->setSliderPosition(nhredux / 5000);
@@ -1194,10 +1184,10 @@ void OphcrackGUI::updateConfig(void) {
 void OphcrackGUI::threadChanged(int x) {
   if (x != crack->arg->nthreads) {
     arg->nthreads = x;
-    threadLabel->setText(QString("%1 (restart required)").arg(x));
+    threadLabel->setText(QString("restart required"));
   }
   else
-    threadLabel->setText(QString("%1").arg(x));
+    threadLabel->setText(QString(""));
 }
 //---------------------------------------------------------------------------
 void OphcrackGUI::hreduxChanged(int x) {
