@@ -48,7 +48,7 @@ TableDialog::TableDialog(TableModel *tableModel, QWidget *parent) :
   // Setup the table view.
 
   tableView->setModel(tableModel);
-  tableView->hideColumn(3);
+  tableView->hideColumn(TableModel::PROGRESS_COL_IDX);
   selectModel = tableView->selectionModel();
 
   QHeaderView *header = tableView->header();
@@ -101,8 +101,8 @@ void TableDialog::moveUp(void) {
 
   // Record whether the items where expanded or not.
 
-  QModelIndex index_prev = tableModel->index(row-1, 0); 
-  QModelIndex index_curr = tableModel->index(row, 0);
+  QModelIndex index_prev = tableModel->index(row-1, TableModel::TABLE_COL_IDX);
+  QModelIndex index_curr = tableModel->index(row, TableModel::TABLE_COL_IDX);
   
   bool expand_prev = tableView->isExpanded(index_prev);
   bool expand_curr = tableView->isExpanded(index_curr);
