@@ -44,6 +44,12 @@ Q_OBJECT
 public:
   TableModel(QObject *parent);
 
+  static const int TABLE_COL_IDX    = 0;
+  static const int DIR_COL_IDX      = 1;
+  static const int STATUS_COL_IDX   = 2;
+  static const int PRELOAD_COL_IDX  = 3;
+  static const int PROGRESS_COL_IDX = 4;
+
   void install(list_t *tables);
   void uninstall(table_kind_t kind);
   void enable(QStandardItem *item, bool value);
